package fi.em.formPlugin;

import kd.bos.bill.BillShowParameter;
import kd.bos.dataentity.entity.DynamicObject;
import kd.bos.dataentity.utils.StringUtils;
import kd.bos.entity.datamodel.ListSelectedRow;
import kd.bos.entity.datamodel.ListSelectedRowCollection;
import kd.bos.entity.operate.result.OperationResult;
import kd.bos.form.CloseCallBack;
import kd.bos.form.FormShowParameter;
import kd.bos.form.ShowFormHelper;
import kd.bos.form.ShowType;
import kd.bos.form.control.Control;
import kd.bos.form.events.AfterDoOperationEventArgs;
import kd.bos.form.events.ClosedCallBackEvent;
import kd.bos.form.field.TextEdit;
import kd.bos.form.operate.AbstractOperate;
import kd.bos.form.plugin.AbstractFormPlugin;
import kd.bos.list.ListFilterParameter;
import kd.bos.list.ListShowParameter;
import kd.bos.orm.query.QCP;
import kd.bos.orm.query.QFilter;
import kd.bos.servicehelper.BusinessDataServiceHelper;

import java.util.EventObject;
import java.util.HashMap;

/**
 * @author cjz
 * @date 2024/11/11 14:49
 * @description:薪酬发放单弹窗选择计提单数据
 */
public class SalaryDataSelectPlugin extends AbstractFormPlugin {


    @Override
    public void registerListener(EventObject e) {
        super.registerListener(e);
        // 对选择计提单按钮添加点击监听
        TextEdit textEdit = getControl("nckd_selectdata");
        textEdit.addClickListener(this);
    }

    @Override
    public void click(EventObject evt) {
        super.click(evt);
        Control control = (Control) evt.getSource();
        String key = control.getKey();
        //当前表单数据
        DynamicObject dynamicObject=this.getModel().getDataEntity(true);
        //点击计提单数据库选择
        if (StringUtils.equalsIgnoreCase("nckd_selectdata", key)) {
            //薪酬计提数据
            ListShowParameter parameter = ShowFormHelper.createShowListForm("nckd_salarydis", false);
            parameter.getListFilterParameter().setOrderBy("nckd_bizdate Desc");
            parameter.setCloseCallBack(new CloseCallBack(this, "actionid"));
            //设置过滤条件
            ListFilterParameter listFilterParameter = new ListFilterParameter();
            //支付组织
            String nckd_zijinzz=dynamicObject.getString("nckd_zijinzz.number");
            //分录类型
            String nckd_entrytype=dynamicObject.getString("nckd_entrytype");
            QFilter qFilter=new QFilter("nckd_zijinzz.number",QCP.equals,nckd_zijinzz);
            qFilter.and("nckd_entrytype",QCP.equals,nckd_entrytype);
            listFilterParameter.setFilter(qFilter);
            parameter.setListFilterParameter(listFilterParameter);
            getView().showForm(parameter);
        }

    }

    //界面回调事件，返回计提单的编号
    @Override
    public void closedCallBack(ClosedCallBackEvent e) {
        super.closedCallBack(e);
        if (e.getReturnData() != null && StringUtils.equals("actionid", e.getActionId())) {
            ListSelectedRowCollection returnData = (ListSelectedRowCollection) e.getReturnData();
            Object[] primaryKeyValues = returnData.getPrimaryKeyValues();
            //获取选择行的主键id
            Long id = (Long) primaryKeyValues[0];
            DynamicObject dynamicObject = BusinessDataServiceHelper.loadSingle(id, "nckd_salarydis");
            //获取计提单单据号
            String billid = dynamicObject.getString("billno");
            //计提单编号
            this.getModel().setValue("nckd_selectdata", billid);
            //计提单id
            this.getModel().setValue("nckd_salaryid",id);
        }
    }

    //点击按钮跳转到薪酬计提单详情页
    public void afterDoOperation(AfterDoOperationEventArgs arg) {
        super.afterDoOperation(arg);
        AbstractOperate op = (AbstractOperate)arg.getSource();
        String key = op.getOperateKey();
        DynamicObject dynamicObject=this.getModel().getDataEntity(true);
        //计提单id
        Long id=dynamicObject.getLong("nckd_salaryid");
        if ("searchsalary".equals(key)) {
            BillShowParameter billShowParameter = new BillShowParameter();
            billShowParameter.setFormId("nckd_salarydis");
            billShowParameter.getOpenStyle().setShowType(ShowType.Modal);
            billShowParameter.setPkId(id);
            this.getView().showForm(billShowParameter);
        }
    }

}
